import type { Metadata } from 'next';
import localFont from 'next/font/local';
import './globals.css';

// Components
import Nav from '@/components/navigation/nav';
import AccessibilityMenu from '@/components/accessibility/accessibilityMenu';

const geistSans = localFont({
  src: './fonts/GeistVF.woff',
  variable: '--font-geist-sans',
  weight: '100 900',
});
const geistMono = localFont({
  src: './fonts/GeistMonoVF.woff',
  variable: '--font-geist-mono',
  weight: '100 900',
});

export const metadata: Metadata = {
  title: 'UniConnect - Reflecting unity and connection',
  description:
    'UniConnect - Reflecting unity and connection within a diverse community.This is an app developed mainly for people to share their stories and experiences.',
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html
      className={`${geistSans.variable} ${geistMono.variable} antialiased`}
      lang='en'
    >
      <body className='relative'>
        <AccessibilityMenu />
        <Nav />
        {children}
      </body>
    </html>
  );
}
